@@ -17,8 +17,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
-#include "../libs/xdgbasedirs_p.h"
-
 #include "akonadi.h"
 #include "akonadiconnection.h"
 #include "serveradaptor.h"
@@ -35,6 +33,9 @@
 #include "nepomukmanager.h"
 #include "debuginterface.h"
 
+#include "../libs/xdgbasedirs_p.h"
+#include "../libs/protocol_p.h"
+
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
 #include <QtCore/QProcess>
@@ -121,6 +122,9 @@ AkonadiServer::AkonadiServer( QObject* parent )
     if ( !dbusAddress.isEmpty() ) {
       connectionSettings.setValue( QLatin1String( "DBUS/Address" ), QLatin1String( dbusAddress ) );
     }
+
+    connect( QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+             SLOT(serviceOwnerChanged(QString,QString,QString)) );
 }
 
 AkonadiServer::~AkonadiServer()
@@ -240,6 +244,14 @@ void AkonadiServer::startDatabaseProcess()
     akFatal() << "or the target file (mysql.conf) could not be written.";
   }
 
+  // MySQL doesn't like world writeable config files (which makes sense), but
+  // our config file somehow ends up being world-writable on some systems for no
+  // apparent reason nevertheless, so fix that
+  const QFile::Permissions allowedPerms = actualFile.permissions()
+      & ( QFile::ReadOwner | QFile::WriteOwner | QFile::ReadGroup | QFile::WriteGroup | QFile::ReadOther );
+  if ( allowedPerms != actualFile.permissions() )
+    actualFile.setPermissions( allowedPerms );
+
   if ( dataDir.isEmpty() )
     akFatal() << "Akonadi server was not able not create database data directory";
 
@@ -331,4 +343,13 @@ void AkonadiServer::stopDatabaseProcess()
   mDatabaseProcess->waitForFinished();
 }
 
+void AkonadiServer::serviceOwnerChanged(const QString & name, const QString & oldOwner, const QString & newOwner)
+{
+  Q_UNUSED( oldOwner );
+  if ( name == QLatin1String( AKONADI_DBUS_CONTROL_SERVICE ) && newOwner.isEmpty() ) {
+    akError() << "Control process died, committing suicide!";
+    quit();
+  }
+}
+
 #include "akonadi.moc"
