@@ -36,6 +36,7 @@
 #include "handler/delete.h"
 #include "handler/expunge.h"
 #include "handler/fetch.h"
+#include "handler/link.h"
 #include "handler/list.h"
 #include "handler/login.h"
 #include "handler/logout.h"
@@ -149,6 +150,10 @@ Handler * Handler::findHandlerForCommandAuthenticated( const QByteArray & comman
       return new Copy();
     if ( command == "COLCOPY" )
       return new ColCopy();
+    if ( command == "LINK" )
+      return new Link( true );
+    if ( command == "UNLINK" )
+      return new Link( false );
 
     return 0;
 }
@@ -223,7 +228,10 @@ void Handler::imapSetToQuery(const ImapSet & set, bool isUid, QueryBuilder & qb)
 
   if ( !isUid && connection()->selectedCollection() >= 0 ) {
     const Location loc = connection()->selectedLocation();
-    if ( loc.resource().name() == QLatin1String("akonadi_search_resource") ) {
+    // FIXME: we probably want to do both paths here in all cases, but that is apparently
+    // non-trivial with SQL
+    if ( loc.resource().name() == QLatin1String("akonadi_search_resource") ||
+         loc.resource().name().contains( QLatin1String("nepomuk") ) ) {
       qb.addTable( LocationPimItemRelation::tableName() );
       qb.addValueCondition( LocationPimItemRelation::leftFullColumnName(), Query::Equals, loc.id() );
       qb.addColumnCondition( LocationPimItemRelation::rightFullColumnName(), Query::Equals,
