@@ -81,7 +81,8 @@ QueryBuilder::QueryBuilder( QueryType type ) :
 #ifndef QUERYBUILDER_UNITTEST
     mQuery( DataStore::self()->database() ),
 #endif
-    mType( type )
+    mType( type ),
+    mDistinct( false )
 {
 }
 
@@ -112,6 +113,8 @@ bool QueryBuilder::exec()
   switch ( mType ) {
     case Select:
       statement += QLatin1String( "SELECT " );
+      if ( mDistinct )
+        statement += QLatin1String( "DISTINCT " );
       Q_ASSERT_X( mColumns.count() > 0, "QueryBuilder::exec()", "No columns specified" );
       statement += mColumns.join( QLatin1String( ", " ) );
       statement += QLatin1String(" FROM ");
@@ -249,3 +252,8 @@ void QueryBuilder::updateColumnValue(const QString & column, const QVariant & va
 {
   mUpdateColumns << qMakePair( column, value );
 }
+
+void QueryBuilder::setDistinct(bool distinct)
+{
+  mDistinct = distinct;
+}
